#!/bin/bash

#---( Zenwalk Build Script
#---( Build Script written for latex_xft_fonts
#---( These fonts are required to display math symbols in LyX compiled with Qt-frontend.
#---( Source URL: ftp://ftp.lyx.org/pub/lyx/contrib/latex-xft-fonts-0.1.tar.gz 
#---( Author: R S Ananda Murthy (rsamurti@airtelbroadband.in)
#---( Date build script was last modified: Saturday, June 30, 2007.


#------------------( Set Package Name & Version )

soft='latex_xft_fonts'
softversion='0.1'
packageversion='48.1'
arch='noarch'


#------------------( Check for source files )


if [ -f latex-xft-fonts-$softversion.tar.gz  ]; then
   echo "Source file .. ok"
else
   echo "Source file does not exit. Downloading it ..."
   wget -c ftp://ftp.lyx.org/pub/lyx/contrib/latex-xft-fonts-$softversion.tar.gz
fi


#------------------( Set Build Location Variables )

buildir=$(pwd)
srcpkg="$buildir/latex-xft-fonts-$softversion.tar.gz"
src="$buildir/latex-xft-fonts-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

#------------------( Clean, prepare the work area and extract the source code )

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest


#------------------( Set Build Ownerships )


chown -R root:root .


#------------------( Move Documentation and TTF Font Files To Correct Location )

mkdir -p $dest/usr/doc/$soft-$softversion
cd $src
cp -a README $dest/usr/doc/$soft-$softversion

mkdir -p $dest/usr/share/fonts/TTF
cp $src/*.ttf $dest/usr/share/fonts/TTF


#------------------( Copy Build The Script )


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( Create The Slackdesc )


mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc 
               |-----handy-ruler------------------------------------------------------|
latex_xft_fonts: LaTeX Xft Fonts (Xft-compatible versions of some LaTeX fonts)
latex_xft_fonts: 
latex_xft_fonts: Some xft-compatible versions of LaTeX fonts for use with visual math
latex_xft_fonts: symbol display in LyX. It is useful primarily for the LyX Qt frontend.
latex_xft_fonts: 
latex_xft_fonts:
latex_xft_fonts:
latex_xft_fonts:
latex_xft_fonts:
latex_xft_fonts:
latex_xft_fonts:
EOF

#------------------( Create the doinst.sh file )


mkdir -p $dest/install
cat <<"EOF" > $dest/install/doinst.sh
( cd usr/share/fonts/TTF
cp fonts.dir fonts.dir.bak
cp fonts.scale fonts.scale.bak
mkfontscale
mkfontdir )
fc-cache
if [ "$DISPLAY" ] ; then
  xset fp rehash
fi
EOF



#------------------( Compress The Package And Clean Up The Work Area )


cd $dest

find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

makepkg -l y -c n $package.tgz
mv $package.tgz ../$package.tgz
rm -rf $src
rm -rf $dest

#------------------( Generate the MD5 Check Sum )


cd $buildir
md5sum $package.tgz > $package.md5
zen_pkgcheck_new.pl $package.tgz
requiredbuilder -z $package.tgz > $package.dep